@@ -34,7 +34,7 @@ def main(cleanup=None):
     parser.add_option("--restore-data", action="store_true", dest="restore_data", help="Restore previously saved objects")
     parser.add_option("--debug", action="store_true", dest="debug", help="Debug mode")
     parser.add_option("--coverage", action="store_true", dest="coverage", help=optparse.SUPPRESS_HELP)
-    parser.add_option("--cprofile", action="store_true", dest="coverage", help=optparse.SUPPRESS_HELP)
+    parser.add_option("--cprofile", action="store_true", dest="cprofile", help=optparse.SUPPRESS_HELP)
 
     # we accept these options, but never check them
     parser.add_option("--no-save", action="store_true", dest="no_save", help=optparse.SUPPRESS_HELP)
@@ -75,35 +75,48 @@ def main(cleanup=None):
     if not r_home:
         raise RuntimeError("Cannot find R binary. Expose it via the `PATH` variable.")
 
-    if sys.platform.startswith("linux"):
-        # respect R_ARCH variable?
+    if not sys.platform.startswith("win"):
         libPath = os.path.join(r_home, "lib")
         ldpaths = os.path.join(r_home, "etc", "ldpaths")
-        if "R_LD_LIBRARY_PATH" not in os.environ or libPath not in os.environ["R_LD_LIBRARY_PATH"]:
+        if (
+            "R_LD_LIBRARY_PATH" not in os.environ
+            or libPath not in os.environ["R_LD_LIBRARY_PATH"]
+        ):
             if os.path.exists(ldpaths):
-                R_LD_LIBRARY_PATH = subprocess.check_output(
-                    ". \"{}\"; echo $R_LD_LIBRARY_PATH".format(ldpaths),
-                    shell=True
-                ).decode("utf-8").strip()
+                R_LD_LIBRARY_PATH = (
+                    subprocess.check_output(
+                        '. "{}"; echo $R_LD_LIBRARY_PATH'.format(ldpaths),
+                        shell=True,
+                    )
+                    .decode("utf-8")
+                    .strip()
+                )
             elif "R_LD_LIBRARY_PATH" in os.environ:
                 R_LD_LIBRARY_PATH = os.environ["R_LD_LIBRARY_PATH"]
             else:
                 R_LD_LIBRARY_PATH = libPath
-
             if libPath not in R_LD_LIBRARY_PATH:
                 R_LD_LIBRARY_PATH = "{}:{}".format(libPath, R_LD_LIBRARY_PATH)
-
-            os.environ['R_LD_LIBRARY_PATH'] = R_LD_LIBRARY_PATH
-
-            if "LD_LIBRARY_PATH" in os.environ:
-                LD_LIBRARY_PATH = "{}:{}".format(R_LD_LIBRARY_PATH, os.environ["LD_LIBRARY_PATH"])
+            os.environ["R_LD_LIBRARY_PATH"] = R_LD_LIBRARY_PATH
+            # respect R_ARCH variable?
+            if sys.platform == "darwin":
+                ld_library_var = "DYLD_FALLBACK_LIBRARY_PATH"
+            else:
+                ld_library_var = "LD_LIBRARY_PATH"
+            if ld_library_var in os.environ:
+                LD_LIBRARY_PATH = "{}:{}".format(
+                    R_LD_LIBRARY_PATH, os.environ[ld_library_var]
+                )
             else:
                 LD_LIBRARY_PATH = R_LD_LIBRARY_PATH
-            os.environ['LD_LIBRARY_PATH'] = LD_LIBRARY_PATH
+            os.environ[ld_library_var] = LD_LIBRARY_PATH
             if sys.argv[0].endswith("radian"):
                 os.execv(sys.argv[0], sys.argv)
             else:
-                os.execv(sys.executable, [sys.executable, "-m", "radian"] + sys.argv[1:])
+                os.execv(
+                    sys.executable,
+                    [sys.executable, "-m", "radian"] + sys.argv[1:],
+                )
 
     RadianApplication(r_home, ver=__version__).run(options, cleanup=cleanup)
 
@@ -202,16 +215,10 @@ class RadianApplication():
         # enable signal handlers
         os.environ["RCHITECT_REGISTER_SIGNAL_HANDLERS"] = "1"
 
-        if sys.platform.startswith("win"):
-            # avoid "using locale code page other than 1252 may cause problems" warning
-            lc_ctype = os.environ.pop('LC_CTYPE', "en_US.UTF-8")
-        else:
-            lc_ctype = None
-
         rchitect.init(args=args, register_signal_handlers=True)
 
         if sys.platform.startswith("win"):
-            rutils.set_locale(lc_ctype = lc_ctype)
+            rutils.set_utf8()
 
         try:
             rutils.source_radian_profile(options.profile)
